@@ -70,15 +70,6 @@ def load_configuration(cfgfiles=None):
         LOGGER.info("Configuration file(s) {} loaded".format(loaded_files))
     else:
         LOGGER.info("No configuration files loaded. Using default values")
-    # dirty hack to set rook url on binder
-    if "ROOK_URL" in os.environ:
-        CONFIG.set("service", "url", os.environ["ROOK_URL"])
-    if "ROOK_MODE" in os.environ:
-        CONFIG.set("service", "mode", os.environ["ROOK_MODE"])
-    if "ROOK_SSL_VERIFY" in os.environ:
-        CONFIG.set("service", "ssl_verify", os.environ["ROOK_SSL_VERIFY"])
-    if "ROOKI_OUTPUT_DIR" in os.environ:
-        CONFIG.set("service", "output_dir", os.environ["ROOKI_OUTPUT_DIR"])
 
 
 def _get_default_config_files_location():
