@@ -2,11 +2,13 @@ import tempfile
 import requests
 from bs4 import BeautifulSoup
 
+import logging
+
 
 class Result(object):
     def __init__(self, response, output_dir=None, verify=False):
         self.response = response
-        self.output_dir = tempfile.mkdtemp(prefix='metalink_', dir=output_dir)
+        self.output_dir = tempfile.mkdtemp(prefix="metalink_", dir=output_dir)
         self.verify = verify
         # cache
         self._xml = None
@@ -78,8 +80,15 @@ class Result(object):
     def download(self):
         try:
             import metalink.download
+
+            if self.verify is False:
+                # TODO: should be handled in metalink
+                import ssl
+
+                ssl._create_default_https_context = ssl._create_unverified_context
             files = metalink.download.get(self.url, self.output_dir, segmented=False)
-        except Exception:
+        except Exception as e:
+            logging.error(f"Could not download files: {e}")
             files = []
         return files
 
